@@ -75,10 +75,7 @@ typedef enum {
 } ncalign_e;
 typedef struct ncplane_options {
   int y;            // vertical placement relative to parent plane
-  union {
-    int x;
-    ncalign_e align;
-  } horiz;          // horizontal placement relative to parent plane
+  int x;            // horizontal placement relative to parent plane
   int rows;         // number of rows, must be positive
   int cols;         // number of columns, must be positive
   void* userptr;    // user curry, may be NULL
@@ -120,14 +117,14 @@ char* notcurses_at_yx(struct notcurses* nc, int yoff, int xoff, uint16_t* stylem
 char* ncplane_at_cursor(struct ncplane* n, uint16_t* stylemask, uint64_t* channels);
 char* ncplane_at_yx(const struct ncplane* n, int y, int x, uint16_t* stylemask, uint64_t* channels);
 typedef enum {
-  NCBLIT_1x1,     // full block                █
-  NCBLIT_2x1,     // full/(upper|left) blocks  ▄█
-  NCBLIT_1x1x4,   // shaded full blocks        ▓▒░█
-  NCBLIT_2x2,     // quadrants                 ▗▐ ▖▄▟▌▙█
-  NCBLIT_4x1,     // four vert/horz levels     █▆▄▂ / ▎▌▊█
-  NCBLIT_BRAILLE, // 4 rows, 2 cols (braille)  ⡀⡄⡆⡇⢀⣀⣄⣆⣇⢠⣠⣤⣦⣧⢰⣰⣴⣶⣷⢸⣸⣼⣾⣿
-  NCBLIT_8x1,     // eight vert/horz levels    █▇▆▅▄▃▂▁ / ▏▎▍▌▋▊▉█
-  NCBLIT_SIXEL,   // 6 rows, 1 col (RGB)
+  NCBLIT_1x1,
+  NCBLIT_2x1,
+  NCBLIT_2x2,
+  NCBLIT_3x2,
+  NCBLIT_4x1,
+  NCBLIT_BRAILLE,
+  NCBLIT_8x1,
+  NCBLIT_SIXEL,
 } ncblitter_e;
 const char* notcurses_str_blitter(ncblitter_e blitter);
 int notcurses_lex_blitter(const char* op, ncblitter_e* blitter);
@@ -135,8 +132,7 @@ uint32_t* ncplane_rgba(const struct ncplane* nc, ncblitter_e blit, int begy, int
 char* ncplane_contents(const struct ncplane* nc, int begy, int begx, int leny, int lenx);
 void* ncplane_set_userptr(struct ncplane* n, void* opaque);
 void* ncplane_userptr(struct ncplane* n);
-int ncplane_resize(struct ncplane* n, int keepy, int keepx, int keepleny,
-                       int keeplenx, int yoff, int xoff, int ylen, int xlen);
+int ncplane_resize(struct ncplane* n, int keepy, int keepx, int keepleny, int keeplenx, int yoff, int xoff, int ylen, int xlen);
 uint64_t ncplane_channels(const struct ncplane* n);
 int ncplane_set_fg_rgb8(struct ncplane* n, int r, int g, int b);
 int ncplane_set_bg_rgb8(struct ncplane* n, int r, int g, int b);
@@ -213,6 +209,7 @@ struct ncvisual* ncvisual_from_plane(const struct ncplane* n, ncblitter_e blit,
 int ncvisual_geom(const struct notcurses* nc, const struct ncvisual* n, const struct ncvisual_options* vopts, int* y, int* x, int* toy, int* tox);
 void ncvisual_destroy(struct ncvisual* ncv);
 int ncvisual_decode(struct ncvisual* nc);
+int ncvisual_decode_loop(struct ncvisual* nc);
 int ncvisual_rotate(struct ncvisual* n, double rads);
 int ncvisual_resize(struct ncvisual* n, int rows, int cols);
 int ncvisual_polyfill_yx(struct ncvisual* n, int y, int x, uint32_t rgba);
@@ -417,6 +414,7 @@ int ncdirect_bg_rgb8(struct ncdirect* n, unsigned r, unsigned g, unsigned b);
 int ncdirect_fg_rgb8(struct ncdirect* n, unsigned r, unsigned g, unsigned b);
 unsigned ncdirect_palette_size(const struct ncdirect* nc);
 int ncdirect_putstr(struct ncdirect* nc, uint64_t channels, const char* utf8);
+int ncdirect_printf_aligned(struct ncdirect* n, int y, ncalign_e align, const char* fmt, ...);
 int ncdirect_fg_rgb(struct ncdirect* n, unsigned rgb);
 int ncdirect_bg_rgb(struct ncdirect* n, unsigned rgb);
 int ncdirect_styles_set(struct ncdirect* n, unsigned stylebits);
